@@ -368,14 +368,15 @@ xml_buffer_parse_error (void *ctxt, const gchar * msg, ...)
 		va_start (params, msg);
 		newmsg = g_strdup_vprintf (msg, params);
 		va_end (params);
-
-		g_assert (NULL != newmsg);
-		newmsg = common_utf8_fix (newmsg);
-		tmp = g_markup_escape_text (newmsg, -1);
-		g_free (newmsg);
-		newmsg = tmp;
 	
-		g_string_append_printf(errors->msg, "<pre>%s</pre>\n", newmsg);
+		/* Do never encode any invalid characters from error messages */
+		if (g_utf8_validate (newmsg, -1, NULL)) {
+			tmp = g_markup_escape_text (newmsg, -1);
+			g_free (newmsg);
+			newmsg = tmp;
+	
+			g_string_append_printf(errors->msg, "<pre>%s</pre>\n", newmsg);
+		}
 		g_free(newmsg);
 	}
 	
@@ -510,7 +511,7 @@ xml_parse_feed (feedParserCtxtPtr fpc)
 	
 	/* we don't like no data */
 	if (0 == fpc->dataLength) {
-		debug1 (DEBUG_PARSING, "common_parse_xml_feed(): empty input while parsing \"%s\"!", fpc->subscription->node->title);
+		debug1 (DEBUG_PARSING, "xml_parse_feed(): empty input while parsing \"%s\"!", fpc->subscription->node->title);
 		g_string_append (fpc->feed->parseErrors, "Empty input!\n");
 		return NULL;
 	}
@@ -518,6 +519,14 @@ xml_parse_feed (feedParserCtxtPtr fpc)
 	errors = g_new0 (struct errorCtxt, 1);
 	errors->msg = fpc->feed->parseErrors;
 	
+	if (!g_utf8_validate (fpc->data, -1, NULL)) {
+		/* We never collect invalid encoding error output to avoid getting
+		   nasty characters inside our error buffer, so we issue a simple
+		   warning here */
+		debug1 (DEBUG_PARSING, "xml_parse_feed(): invalid UTF-8 encoding while parsing \"%s\"!", fpc->subscription->node->title);
+		g_string_append_printf (fpc->feed->parseErrors, _("Invalid encoding in feed \"%s\"!"), fpc->subscription->node->title);
+	}
+	
 	fpc->doc = xml_parse (fpc->data, (size_t)fpc->dataLength, fpc->recovery, errors);
 	if (!fpc->doc) {
 		debug1 (DEBUG_PARSING, "xmlReadMemory: could not parse feed \"%s\"!", fpc->subscription->node->title);
